import { Utility } from '@aws-lambda-powertools/commons';
import type { TracerInterface } from '.';
import type { HandlerMethodDecorator, TracerOptions, MethodDecorator, CaptureLambdaHandlerOptions, CaptureMethodOptions } from './types';
import { type ProviderServiceInterface } from './provider';
import { type Segment, Subsegment } from 'aws-xray-sdk-core';
declare class Tracer extends Utility implements TracerInterface {
    provider: ProviderServiceInterface;
    private captureError;
    private captureHTTPsRequests;
    private captureResponse;
    private customConfigService?;
    private envVarsService;
    private serviceName;
    private tracingEnabled;
    constructor(options?: TracerOptions);
    addErrorAsMetadata(error: Error, remote?: boolean): void;
    addResponseAsMetadata(data?: unknown, methodName?: string): void;
    addServiceNameAnnotation(): void;
    annotateColdStart(): void;
    captureAWS<T>(aws: T): T;
    captureAWSClient<T>(service: T): T;
    captureAWSv3Client<T>(service: T): T;
    captureLambdaHandler(options?: CaptureLambdaHandlerOptions): HandlerMethodDecorator;
    captureMethod(options?: CaptureMethodOptions): MethodDecorator;
    getRootXrayTraceId(): string | undefined;
    getSegment(): Segment | Subsegment | undefined;
    isTraceSampled(): boolean;
    isTracingEnabled(): boolean;
    putAnnotation(key: string, value: string | number | boolean): void;
    putMetadata(key: string, value: unknown, namespace?: string | undefined): void;
    setSegment(segment: Segment | Subsegment): void;
    private getCustomConfigService;
    private getEnvVarsService;
    private isAmplifyCli;
    private isLambdaExecutionEnv;
    private isLambdaSamCli;
    private setCaptureError;
    private setCaptureHTTPsRequests;
    private setCaptureResponse;
    private setCustomConfigService;
    private setEnvVarsService;
    private setOptions;
    private setServiceName;
    private setTracingEnabled;
}
export { Tracer };
//# sourceMappingURL=Tracer.d.ts.map