"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureLambdaHandler = void 0;
const middleware_1 = require("@aws-lambda-powertools/commons/lib/middleware");
const captureLambdaHandler = (target, options) => {
    let lambdaSegment;
    let handlerSegment;
    const setCleanupFunction = (request) => {
        request.internal = {
            ...request.internal,
            [middleware_1.TRACER_KEY]: close,
        };
    };
    const open = () => {
        const segment = target.getSegment();
        if (segment === undefined) {
            return;
        }
        lambdaSegment = segment;
        handlerSegment = lambdaSegment.addNewSubsegment(`## ${process.env._HANDLER}`);
        target.setSegment(handlerSegment);
    };
    const close = () => {
        if (handlerSegment === undefined || lambdaSegment === null) {
            return;
        }
        try {
            handlerSegment.close();
        }
        catch (error) {
            console.warn(`Failed to close or serialize segment, ${handlerSegment.name}. We are catching the error but data might be lost.`, error);
        }
        target.setSegment(lambdaSegment);
    };
    const captureLambdaHandlerBefore = async (request) => {
        if (target.isTracingEnabled()) {
            open();
            setCleanupFunction(request);
            target.annotateColdStart();
            target.addServiceNameAnnotation();
        }
    };
    const captureLambdaHandlerAfter = async (request) => {
        if (target.isTracingEnabled()) {
            if (options?.captureResponse ?? true) {
                target.addResponseAsMetadata(request.response, process.env._HANDLER);
            }
            close();
        }
    };
    const captureLambdaHandlerError = async (request) => {
        if (target.isTracingEnabled()) {
            target.addErrorAsMetadata(request.error);
            close();
        }
    };
    return {
        before: captureLambdaHandlerBefore,
        after: captureLambdaHandlerAfter,
        onError: captureLambdaHandlerError,
    };
};
exports.captureLambdaHandler = captureLambdaHandler;
